==> teachable-school-manager-1.2.1.tar.gz: teachable-school-manager-1.2.1/setup.py <==
"""A setuptools based setup module.
See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
Modified by Madoshakalaka@Github (dependency links added)
"""

# io.open is needed for projects that support Python 2.7
# It ensures open() defaults to text mode with universal newlines,
# and accepts an argument to specify the text encoding
# Python 3 only projects can skip this import
from io import open
from os import path

# Always prefer setuptools over distutils
from setuptools import setup, find_packages

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="teachable-school-manager",  # Required
    version="1.2.1",  # Required
    description="Manage your Teachable school using the unofficial Teachable API",  # Optional
    long_description=long_description,  # Optional
    long_description_content_type="text/markdown",  # Optional (see note above)
    url="https://github.com/stezz/teachable-scripts",  # Optional
    author="Stefano Mosconi",  # Optional
    author_email="stefano.mosconi@gmail.com",  # Optional
    classifiers=[  # Optional
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 4 - Beta",
        # Indicate who your project is intended for
        "Intended Audience :: Developers",
        "Topic :: Education",
        # Pick your license as you wish
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    keywords="scripts teachable",  # Optional
    packages=find_packages(exclude=["contrib", "docs", "tests"]),  # Required
    python_requires=">3.7, <4",
    install_requires=[
        "jinja2==2.11.2",
        "pyexcel==0.6.6",
        "pyexcel-xlsx==0.6.0",
        "pytablewriter[excel,html]==0.58.0",
        "requests==2.25.0",
    ],  # Optional
    extras_require={"dev": []},  # Optional
    dependency_links=[],
    data_files=[("etc", ["etc/config_example.ini", "etc/logconf.ini"]),
                ("templates", ["templates/email_inactive.txt",
                               "templates/email_notstarted.txt",
                               "templates/weekly_report.html"])],
    entry_points={"console_scripts": ["remind=scripts.remind:main", "enroll=scripts.enroll:main"]},  # Optional
    # scripts=["scripts/remind.py"],  # Optional
    project_urls={  # Optional
        "Bug Reports": "https://github.com/stezz/teachable-scripts/issues",
        #        "Funding": "https://donate.pypi.org",
        #        "Say Thanks!": "http://saythanks.io/to/example",
        "Source": "https://github.com/stezz/teachable-scripts/",
    },
)

==> teachable-school-manager-1.2.4.tar.gz: teachable-school-manager-1.2.4/setup.py <==
"""A setuptools based setup module.
See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
Modified by Madoshakalaka@Github (dependency links added)
"""

# io.open is needed for projects that support Python 2.7
# It ensures open() defaults to text mode with universal newlines,
# and accepts an argument to specify the text encoding
# Python 3 only projects can skip this import
from io import open
from os import path

# Always prefer setuptools over distutils
from setuptools import setup, find_packages

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="teachable-school-manager",  # Required
    version="1.2.4",  # Required
    description="Manage your Teachable school using the unofficial Teachable API",  # Optional
    long_description=long_description,  # Optional
    long_description_content_type="text/markdown",  # Optional (see note above)
    url="https://github.com/stezz/teachable-scripts",  # Optional
    author="Stefano Mosconi",  # Optional
    author_email="stefano.mosconi@gmail.com",  # Optional
    classifiers=[  # Optional
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 4 - Beta",
        # Indicate who your project is intended for
        "Intended Audience :: Developers",
        "Topic :: Education",
        # Pick your license as you wish
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    keywords="scripts teachable",  # Optional
    packages=find_packages(exclude=["contrib", "docs", "tests"]),  # Required
    python_requires=">3.7, <4",
    install_requires=[
        "jinja2==2.11.2",
        "pyexcel==0.6.6",
        "pyexcel-xlsx==0.6.0",
        "pytablewriter[excel,html]==0.58.0",
        "requests==2.25.0",
        "schedule==0.6.0",
    ],  # Optional
    extras_require={"dev": []},  # Optional
    dependency_links=[],
    # these directories need to be synced with whatever is in TeachableAPI as DEFAULT_DIRS
    data_files=[(path.join("etc", "teachable"), ["etc/config_example.ini", "etc/logconf.ini"]),
                (path.join('templates', 'teachable'), ["templates/email_inactive.txt",
                                                       "templates/email_notstarted.txt",
                                                       "templates/weekly_report.html"])],
    entry_points={"console_scripts": ["remind=scripts.remind:main",
                                      "enroll=scripts.enroll:main",
                                      "scheduler=scripts.scheduler:main"]},  # Optional
    # scripts=["scripts/remind.py"],  # Optional
    project_urls={  # Optional
        "Bug Reports": "https://github.com/stezz/teachable-scripts/issues",
        #        "Funding": "https://donate.pypi.org",
        #        "Say Thanks!": "http://saythanks.io/to/example",
        "Source": "https://github.com/stezz/teachable-scripts/",
    },
)
